Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/matomo-org/matomo.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authormattab <matthieu.aubry@gmail.com>2013-07-23 11:52:15 +0400
committermattab <matthieu.aubry@gmail.com>2013-07-23 11:52:15 +0400
commit5104d94f3b2250f766b9c520e2da8da9b4cab2e9 (patch)
tree5f30daf7bc14373fb1bbd0504ce11a771dafc02f /core/ScheduledTask.php
parentae4b1f4e38077b174e4df5b7d4513d63fe026a24 (diff)
Refs #4059 Work in progress: Conversion to use Namespaces of dozen more classes
Removed many Piwik_ functions, in Piwik 2 it is best practise to use the methods calls instead Todo: finish converting core/ classes + convert plugins/ classes to use \Piwik\Plugin namespace + fix build + Merge master
Diffstat (limited to 'core/ScheduledTask.php')
-rw-r--r--core/ScheduledTask.php18
1 files changed, 11 insertions, 7 deletions
diff --git a/core/ScheduledTask.php b/core/ScheduledTask.php
index 585d793b91..8d9c368c54 100644
--- a/core/ScheduledTask.php
+++ b/core/ScheduledTask.php
@@ -9,13 +9,18 @@
* @package Piwik
*/
+namespace Piwik;
+
+use Exception;
+use Piwik\ScheduledTime;
+
/**
* Piwik_ScheduledTask is used by the task scheduler and by plugins to configure runnable tasks.
*
* @package Piwik
- * @subpackage Piwik_ScheduledTask
+ * @subpackage ScheduledTask
*/
-class Piwik_ScheduledTask
+class ScheduledTask
{
const LOWEST_PRIORITY = 12;
const LOW_PRIORITY = 9;
@@ -49,7 +54,7 @@ class Piwik_ScheduledTask
/**
* The scheduled time policy
- * @var Piwik_ScheduledTime
+ * @var ScheduledTime
*/
var $scheduledTime;
@@ -110,10 +115,9 @@ class Piwik_ScheduledTask
return $this->methodParameter;
}
-
/**
* Return scheduled time
- * @return Piwik_ScheduledTime
+ * @return ScheduledTime
*/
public function getScheduledTime()
{
@@ -131,7 +135,7 @@ class Piwik_ScheduledTask
/**
* Return the task priority. The priority will be an integer whose value is
- * between Piwik_ScheduledTask::HIGH_PRIORITY and Piwik_ScheduledTask::LOW_PRIORITY.
+ * between ScheduledTask::HIGH_PRIORITY and ScheduledTask::LOW_PRIORITY.
*
* @return int
*/
@@ -9,13 +9,18 @@
/**
- * Piwik_ScheduledTask is used by the task scheduler and by plugins to configure runnable tasks.
+ * ScheduledTask is used by the task scheduler and by plugins to configure runnable tasks.
*
* @package Piwik